
.. py:currentmodule:: pythreejs

Line3
====================================================

.. Use autoclass to fill any memebers not manually specified.
   This ensures it picks up any members in overridden classes.

.. autohastraits:: Line3(start=[0,0,0], end=[0,0,0], )
    :members:
    :undoc-members:


    Inherits :py:class:`~pythreejs.ThreeWidget`.

    Three.js docs: https://threejs.org/docs/#api/math/Line3


    .. py:attribute:: start

        .. sourcecode:: python

            Vector3(default_value=[0,0,0]).tag(sync=True)

    .. py:attribute:: end

        .. sourcecode:: python

            Vector3(default_value=[0,0,0]).tag(sync=True)

